<?xml version='1.0'?>

<xsl:stylesheet
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        version    = '1.0'>

<xsl:output method='wml' indent='no'/>

<!-- ========================================================= -->
<!-- The root template                                         -->
<!-- ========================================================= -->
<xsl:template match='/'>
  <wml>
    <xsl:apply-templates select="RequestContext/WorkItem"/>
  </wml>
</xsl:template>

<!-- ========================================================= -->
<!-- The WorkItem template shows InContainer-elements and      -->
<!-- creates an input-mask for the OutContainer-elements       -->
<!-- ========================================================= -->
<xsl:template match='RequestContext/WorkItem'>
  <card><xsl:attribute name="title"><xsl:value-of select='Name'/></xsl:attribute>

    <template>
      <do label="OK" type="accept" name="complete">
        <go href="/MQWFClient/servlet/Main">
          <postfield name="command" value="checkInWorkItem"/>
          <postfield name="id"><xsl:attribute name="value"><xsl:value-of select='PersistentOid'/></xsl:attribute></postfield>
          <xsl:for-each select='OutContainer/StructMembers'>
            <xsl:apply-templates select="ContainerElement" mode="postfields"/>
          </xsl:for-each>
          <postfield name="returnCode" value="0"/>
        </go>
      </do>
      <do label="Cancel" type="accept" name="cancel">
        <go href="/MQWFClient/servlet/Main">
          <postfield name="command" value="cancelWorkItem"/>
          <postfield name="id"><xsl:attribute name="value"><xsl:value-of select='PersistentOid'/></xsl:attribute></postfield>
        </go>
      </do>
    </template>

    <p>
        <xsl:for-each select='InContainer/StructMembers'>
          <xsl:apply-templates select="ContainerElement" mode="in"/>
        </xsl:for-each>

        <xsl:for-each select='OutContainer/StructMembers'>
          <xsl:apply-templates select="ContainerElement" mode="out"/>
        </xsl:for-each>
     </p>
   </card>
</xsl:template>


<!-- ========================================================== -->
<!-- The (In)ContainerElement template to show data of fields   -->
<!-- not contained in the output container.                     -->
<!-- ========================================================== -->
<xsl:template match="ContainerElement" mode="in">
  <xsl:variable name="name"><xsl:value-of select='Name'/></xsl:variable>

  <xsl:if test="IsStruct[.='false']">

    <xsl:variable name="existsInOut"></xsl:variable>

    <xsl:for-each select="//OutContainer/StructMembers/ContainerElement">
        <xsl:variable name="existsInOut">true</xsl:variable>
    </xsl:for-each>

    <xsl:value-of select='$existsInOut'/>
    <xsl:if test="$existsInOut=true">
      <xsl:value-of select='Name'/>: <xsl:value-of select='Value'/><br/>
    </xsl:if>
  </xsl:if>

  <xsl:if test="IsStruct[.='true']">
    <xsl:for-each select='StructMembers'>
          <xsl:apply-templates select="ContainerElement" mode="in"/>
    </xsl:for-each>
  </xsl:if>
</xsl:template>


<!-- ========================================================== -->
<!-- The (Out)ContainerElement template to create inputfields   -->
<!-- It uses reucrsion to access datastuctures within elements. -->
<!-- ========================================================== -->
<xsl:template match="ContainerElement" mode="out">
  <xsl:if test="IsStruct[.='false']">
    <xsl:value-of select='Name'/>: <input type="text">
                                        <xsl:attribute name="name"><xsl:value-of select='Name'/></xsl:attribute>
                                        <xsl:attribute name="value"><xsl:value-of select='Value'/></xsl:attribute>
                                   </input><br/>
  </xsl:if>
  <xsl:if test="IsStruct[.='true']">
    <xsl:for-each select='StructMembers'>
          <xsl:apply-templates select="ContainerElement" mode="out"/>
    </xsl:for-each>
  </xsl:if>
</xsl:template>

<!-- ========================================================== -->
<!-- The ContainerElement template to create postfields         -->
<!-- ========================================================== -->
<xsl:template match="ContainerElement" mode="postfields">
  <xsl:if test="IsStruct[.='false']">
    <postfield>
        <xsl:attribute name="name"><xsl:value-of select='FullName'/></xsl:attribute>
        <xsl:attribute name="value">$(<xsl:value-of select='Name'/>)</xsl:attribute>
    </postfield>
  </xsl:if>
  <xsl:if test="IsStruct[.='true']">
    <xsl:for-each select='StructMembers'>
          <xsl:apply-templates select="ContainerElement" mode="postfields"/>
    </xsl:for-each>
  </xsl:if>
</xsl:template>


</xsl:stylesheet>
