/*BEGIN CMVC */
//*************************************************************************
//
//  Workfile: %W%
//  Last update: %E% %U%
//  SCCS path, id: %F% %I%
//
//************************************************************************/
/*END CMVC */
/*BEGIN COPYRIGHT */
//*************************************************************************
//
//  Licensed Materials - Property of IBM
//  WA81 SupportPac
//  (c) Copyright IBM Corp. 1999, 2001
//  US Government Users Restricted Rights - Use, duplication or
//  disclosure restricted by GSA ADP Schedule Contract
//  with IBM Corp.
//
//************************************************************************/
/*END COPYRIGHT */
/*BEGIN DISCLAIMER */
//*************************************************************************
//  DISCLAIMER
//  ----------
//  This material contains programming source code for your consideration.
//  These examples have not been thoroughly tested under all conditions.
//  IBM, therefore, cannot guarantee or imply reliability, serviceability,
//  or function of these programs.
//  ALL PROGRAMS CONTAINED HEREIN ARE PROVIDED TO YOU "AS IS", WITHOUT ANY
//  WARRANTIES (EXPRESS OR IMPLIED) OR SUPPORT WHATSOEVER, INCLUDING BUT
//  NOT LIMITED TO ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
//  FOR A PARTICULAR PURPOSE.
//************************************************************************/
/*END DISCLAIMER */

package com.ibm.workflow.servlet.sample;

import javax.servlet.http.*;
import com.ibm.workflow.servlet.client.*;

/**
* This sample handler shows how to select different viewers depending on
* the client's capabilities.
*/
public class ViewerSelectionHandler extends GenericCommandHandler
{
  /**
  * Returns a String that contains information about this handler.
  * @return the version string
  */
  public final String getHandlerInfo()
  {
    return "MQWF Sample - Set Viewer per Client V0.9";
  }

  /**
  * This method is called whenever a new user has logged on.
  * It checks the <code>Accept</code> request header to see if the
  * client supports WML and if so, it sets the viewer to be used to
  * {@link com.ibm.workflow.servlet.client.XMLViewer XMLViewer}. If
  * the broswer does not support WML, the viewer will be left unset
  * causing the <code>DefaultViewer</code> as set up in the
  * <code>WebClient.properties</code> configuration file to be used.
  * @param context The {@link RequestContext} for the newly added session.
  */
  public final void onLogon(RequestContext ctx)
  {
    HttpServletRequest request = ctx.getRequest();
    // ctx.log("'" + request.getHeader("User-Agent") + "' accepts '" +
    //         request.getHeader("Accept") + "'", false);

    Viewer viewer = null;
    String accept = request.getHeader("Accept");

    if (accept != null && accept.indexOf(ResponsePage.MIMETYPE_WML) != -1)
    {
      if (xmlViewer == null)
      {
        xmlViewer = new XMLViewer();
        xmlViewer.init(ctx.getConfig());
      }

      viewer = xmlViewer;
      ctx.log("Setting XMLViewer for " + ctx.getUserID(), false);
    }

    if (viewer == null && "FUSSI".equals(ctx.getUserID()))
    {
      viewer = new PortletViewer();
      viewer.init(ctx.getConfig());
    }

    ctx.setViewer(viewer);
  }

  private XMLViewer xmlViewer = null;
}
